@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -23,6 +23,7 @@ except ImportError as error:
     get_surfaces = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -42,9 +43,8 @@ class DXFImport(FrozenClass):
         )
     else:
         get_surfaces = get_surfaces
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -112,7 +112,7 @@ class DXFImport(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -121,11 +121,41 @@ class DXFImport(FrozenClass):
             return ["type(" + name + ")"]
         diff_list = list()
         if other._file_path != self._file_path:
-            diff_list.append(name + ".file_path")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._file_path)
+                    + ", other="
+                    + str(other._file_path)
+                    + ")"
+                )
+                diff_list.append(name + ".file_path" + val_str)
+            else:
+                diff_list.append(name + ".file_path")
         if other._surf_dict != self._surf_dict:
-            diff_list.append(name + ".surf_dict")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._surf_dict)
+                    + ", other="
+                    + str(other._surf_dict)
+                    + ")"
+                )
+                diff_list.append(name + ".surf_dict" + val_str)
+            else:
+                diff_list.append(name + ".surf_dict")
         if other._BC_list != self._BC_list:
-            diff_list.append(name + ".BC_list")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._BC_list)
+                    + ", other="
+                    + str(other._BC_list)
+                    + ")"
+                )
+                diff_list.append(name + ".BC_list" + val_str)
+            else:
+                diff_list.append(name + ".BC_list")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -166,6 +196,25 @@ class DXFImport(FrozenClass):
         DXFImport_dict["__class__"] = "DXFImport"
         return DXFImport_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        file_path_val = self.file_path
+        if self.surf_dict is None:
+            surf_dict_val = None
+        else:
+            surf_dict_val = self.surf_dict.copy()
+        if self.BC_list is None:
+            BC_list_val = None
+        else:
+            BC_list_val = self.BC_list.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            file_path=file_path_val, surf_dict=surf_dict_val, BC_list=BC_list_val
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
