@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .HoleMag import HoleMag
 
 # Import all class method
@@ -70,9 +70,8 @@ except ImportError as error:
     has_magnet = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Magnet import Magnet
-from .Material import Material
 
 
 class HoleMLSRPM(HoleMag):
@@ -196,9 +195,8 @@ class HoleMLSRPM(HoleMag):
         )
     else:
         has_magnet = has_magnet
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -324,7 +322,7 @@ class HoleMLSRPM(HoleMag):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -334,28 +332,114 @@ class HoleMLSRPM(HoleMag):
         diff_list = list()
 
         # Check the properties inherited from HoleMag
-        diff_list.extend(super(HoleMLSRPM, self).compare(other, name=name))
-        if other._H1 != self._H1:
-            diff_list.append(name + ".H1")
-        if other._W0 != self._W0:
-            diff_list.append(name + ".W0")
-        if other._W1 != self._W1:
-            diff_list.append(name + ".W1")
-        if other._W2 != self._W2:
-            diff_list.append(name + ".W2")
-        if other._R1 != self._R1:
-            diff_list.append(name + ".R1")
-        if other._R2 != self._R2:
-            diff_list.append(name + ".R2")
-        if other._R3 != self._R3:
-            diff_list.append(name + ".R3")
+        diff_list.extend(
+            super(HoleMLSRPM, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
+        if (
+            other._H1 is not None
+            and self._H1 is not None
+            and isnan(other._H1)
+            and isnan(self._H1)
+        ):
+            pass
+        elif other._H1 != self._H1:
+            if is_add_value:
+                val_str = " (self=" + str(self._H1) + ", other=" + str(other._H1) + ")"
+                diff_list.append(name + ".H1" + val_str)
+            else:
+                diff_list.append(name + ".H1")
+        if (
+            other._W0 is not None
+            and self._W0 is not None
+            and isnan(other._W0)
+            and isnan(self._W0)
+        ):
+            pass
+        elif other._W0 != self._W0:
+            if is_add_value:
+                val_str = " (self=" + str(self._W0) + ", other=" + str(other._W0) + ")"
+                diff_list.append(name + ".W0" + val_str)
+            else:
+                diff_list.append(name + ".W0")
+        if (
+            other._W1 is not None
+            and self._W1 is not None
+            and isnan(other._W1)
+            and isnan(self._W1)
+        ):
+            pass
+        elif other._W1 != self._W1:
+            if is_add_value:
+                val_str = " (self=" + str(self._W1) + ", other=" + str(other._W1) + ")"
+                diff_list.append(name + ".W1" + val_str)
+            else:
+                diff_list.append(name + ".W1")
+        if (
+            other._W2 is not None
+            and self._W2 is not None
+            and isnan(other._W2)
+            and isnan(self._W2)
+        ):
+            pass
+        elif other._W2 != self._W2:
+            if is_add_value:
+                val_str = " (self=" + str(self._W2) + ", other=" + str(other._W2) + ")"
+                diff_list.append(name + ".W2" + val_str)
+            else:
+                diff_list.append(name + ".W2")
+        if (
+            other._R1 is not None
+            and self._R1 is not None
+            and isnan(other._R1)
+            and isnan(self._R1)
+        ):
+            pass
+        elif other._R1 != self._R1:
+            if is_add_value:
+                val_str = " (self=" + str(self._R1) + ", other=" + str(other._R1) + ")"
+                diff_list.append(name + ".R1" + val_str)
+            else:
+                diff_list.append(name + ".R1")
+        if (
+            other._R2 is not None
+            and self._R2 is not None
+            and isnan(other._R2)
+            and isnan(self._R2)
+        ):
+            pass
+        elif other._R2 != self._R2:
+            if is_add_value:
+                val_str = " (self=" + str(self._R2) + ", other=" + str(other._R2) + ")"
+                diff_list.append(name + ".R2" + val_str)
+            else:
+                diff_list.append(name + ".R2")
+        if (
+            other._R3 is not None
+            and self._R3 is not None
+            and isnan(other._R3)
+            and isnan(self._R3)
+        ):
+            pass
+        elif other._R3 != self._R3:
+            if is_add_value:
+                val_str = " (self=" + str(self._R3) + ", other=" + str(other._R3) + ")"
+                diff_list.append(name + ".R3" + val_str)
+            else:
+                diff_list.append(name + ".R3")
         if (other.magnet_0 is None and self.magnet_0 is not None) or (
             other.magnet_0 is not None and self.magnet_0 is None
         ):
             diff_list.append(name + ".magnet_0 None mismatch")
         elif self.magnet_0 is not None:
             diff_list.extend(
-                self.magnet_0.compare(other.magnet_0, name=name + ".magnet_0")
+                self.magnet_0.compare(
+                    other.magnet_0,
+                    name=name + ".magnet_0",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
@@ -415,6 +499,48 @@ class HoleMLSRPM(HoleMag):
         HoleMLSRPM_dict["__class__"] = "HoleMLSRPM"
         return HoleMLSRPM_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        H1_val = self.H1
+        W0_val = self.W0
+        W1_val = self.W1
+        W2_val = self.W2
+        R1_val = self.R1
+        R2_val = self.R2
+        R3_val = self.R3
+        if self.magnet_0 is None:
+            magnet_0_val = None
+        else:
+            magnet_0_val = self.magnet_0.copy()
+        Zh_val = self.Zh
+        if self.mat_void is None:
+            mat_void_val = None
+        else:
+            mat_void_val = self.mat_void.copy()
+        if self.magnetization_dict_offset is None:
+            magnetization_dict_offset_val = None
+        else:
+            magnetization_dict_offset_val = self.magnetization_dict_offset.copy()
+        Alpha0_val = self.Alpha0
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            H1=H1_val,
+            W0=W0_val,
+            W1=W1_val,
+            W2=W2_val,
+            R1=R1_val,
+            R2=R2_val,
+            R3=R3_val,
+            magnet_0=magnet_0_val,
+            Zh=Zh_val,
+            mat_void=mat_void_val,
+            magnetization_dict_offset=magnetization_dict_offset_val,
+            Alpha0=Alpha0_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -568,13 +694,20 @@ class HoleMLSRPM(HoleMag):
     def _set_magnet_0(self, value):
         """setter of magnet_0"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "magnet_0"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Magnet = import_class("pyleecan.Classes", "Magnet", "magnet_0")
             value = Magnet()
         check_var("magnet_0", value, "Magnet")
         self._magnet_0 = value
