@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .ImportMatrix import ImportMatrix
 
 # Import all class method
@@ -28,8 +28,8 @@ except ImportError as error:
     init_vector = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .ImportGenVectSin import ImportGenVectSin
 
 
 class ImportGenMatrixSin(ImportMatrix):
@@ -61,9 +61,8 @@ class ImportGenMatrixSin(ImportMatrix):
         )
     else:
         init_vector = init_vector
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -122,7 +121,7 @@ class ImportGenMatrixSin(ImportMatrix):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -132,7 +131,11 @@ class ImportGenMatrixSin(ImportMatrix):
         diff_list = list()
 
         # Check the properties inherited from ImportMatrix
-        diff_list.extend(super(ImportGenMatrixSin, self).compare(other, name=name))
+        diff_list.extend(
+            super(ImportGenMatrixSin, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if (other.sin_list is None and self.sin_list is not None) or (
             other.sin_list is not None and self.sin_list is None
         ):
@@ -145,7 +148,10 @@ class ImportGenMatrixSin(ImportMatrix):
             for ii in range(len(other.sin_list)):
                 diff_list.extend(
                     self.sin_list[ii].compare(
-                        other.sin_list[ii], name=name + ".sin_list[" + str(ii) + "]"
+                        other.sin_list[ii],
+                        name=name + ".sin_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         # Filter ignore differences
@@ -201,6 +207,21 @@ class ImportGenMatrixSin(ImportMatrix):
         ImportGenMatrixSin_dict["__class__"] = "ImportGenMatrixSin"
         return ImportGenMatrixSin_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.sin_list is None:
+            sin_list_val = None
+        else:
+            sin_list_val = list()
+            for obj in self.sin_list:
+                sin_list_val.append(obj.copy())
+        is_transpose_val = self.is_transpose
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(sin_list=sin_list_val, is_transpose=is_transpose_val)
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -220,6 +241,15 @@ class ImportGenMatrixSin(ImportMatrix):
         """setter of sin_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "sin_list"
