@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Import import Import
 
 # Import all class method
@@ -23,6 +23,7 @@ except ImportError as error:
     edit_matrix = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -42,9 +43,8 @@ class ImportMatrix(Import):
         )
     else:
         edit_matrix = edit_matrix
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -95,7 +95,7 @@ class ImportMatrix(Import):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -105,9 +105,23 @@ class ImportMatrix(Import):
         diff_list = list()
 
         # Check the properties inherited from Import
-        diff_list.extend(super(ImportMatrix, self).compare(other, name=name))
+        diff_list.extend(
+            super(ImportMatrix, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._is_transpose != self._is_transpose:
-            diff_list.append(name + ".is_transpose")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_transpose)
+                    + ", other="
+                    + str(other._is_transpose)
+                    + ")"
+                )
+                diff_list.append(name + ".is_transpose" + val_str)
+            else:
+                diff_list.append(name + ".is_transpose")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -145,6 +159,15 @@ class ImportMatrix(Import):
         ImportMatrix_dict["__class__"] = "ImportMatrix"
         return ImportMatrix_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        is_transpose_val = self.is_transpose
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(is_transpose=is_transpose_val)
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
