@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .InputCurrent import InputCurrent
 
 # Import all class method
@@ -26,10 +26,8 @@ except ImportError as error:
 from ..Classes.ImportMatrixVal import ImportMatrixVal
 from numpy import ndarray
 from numpy import array, array_equal
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .ImportMatrix import ImportMatrix
-from .ImportGenPWM import ImportGenPWM
-from .OP import OP
 
 
 class InputFlux(InputCurrent):
@@ -46,9 +44,8 @@ class InputFlux(InputCurrent):
         )
     else:
         gen_input = gen_input
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -64,17 +61,22 @@ class InputFlux(InputCurrent):
         B_enforced=None,
         Is=None,
         Ir=None,
+        Is_harm=None,
         rot_dir=None,
         angle_rotor_initial=0,
         PWM=None,
         phase_dir=None,
         current_dir=None,
+        is_periodicity_t=False,
+        is_periodicity_a=False,
+        is_generator=False,
         time=None,
         angle=None,
         Nt_tot=2048,
         Nrev=None,
         Na_tot=2048,
         OP=None,
+        t_final=None,
         init_dict=None,
         init_str=None,
     ):
@@ -113,6 +115,8 @@ class InputFlux(InputCurrent):
                 Is = init_dict["Is"]
             if "Ir" in list(init_dict.keys()):
                 Ir = init_dict["Ir"]
+            if "Is_harm" in list(init_dict.keys()):
+                Is_harm = init_dict["Is_harm"]
             if "rot_dir" in list(init_dict.keys()):
                 rot_dir = init_dict["rot_dir"]
             if "angle_rotor_initial" in list(init_dict.keys()):
@@ -123,6 +127,12 @@ class InputFlux(InputCurrent):
                 phase_dir = init_dict["phase_dir"]
             if "current_dir" in list(init_dict.keys()):
                 current_dir = init_dict["current_dir"]
+            if "is_periodicity_t" in list(init_dict.keys()):
+                is_periodicity_t = init_dict["is_periodicity_t"]
+            if "is_periodicity_a" in list(init_dict.keys()):
+                is_periodicity_a = init_dict["is_periodicity_a"]
+            if "is_generator" in list(init_dict.keys()):
+                is_generator = init_dict["is_generator"]
             if "time" in list(init_dict.keys()):
                 time = init_dict["time"]
             if "angle" in list(init_dict.keys()):
@@ -135,6 +145,8 @@ class InputFlux(InputCurrent):
                 Na_tot = init_dict["Na_tot"]
             if "OP" in list(init_dict.keys()):
                 OP = init_dict["OP"]
+            if "t_final" in list(init_dict.keys()):
+                t_final = init_dict["t_final"]
         # Set the properties (value check and convertion are done in setter)
         self.per_a = per_a
         self.per_t = per_t
@@ -148,17 +160,22 @@ class InputFlux(InputCurrent):
         super(InputFlux, self).__init__(
             Is=Is,
             Ir=Ir,
+            Is_harm=Is_harm,
             rot_dir=rot_dir,
             angle_rotor_initial=angle_rotor_initial,
             PWM=PWM,
             phase_dir=phase_dir,
             current_dir=current_dir,
+            is_periodicity_t=is_periodicity_t,
+            is_periodicity_a=is_periodicity_a,
+            is_generator=is_generator,
             time=time,
             angle=angle,
             Nt_tot=Nt_tot,
             Nrev=Nrev,
             Na_tot=Na_tot,
             OP=OP,
+            t_final=t_final,
         )
         # The class is frozen (in InputCurrent init), for now it's impossible to
         # add new properties
@@ -212,7 +229,7 @@ class InputFlux(InputCurrent):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -222,19 +239,71 @@ class InputFlux(InputCurrent):
         diff_list = list()
 
         # Check the properties inherited from InputCurrent
-        diff_list.extend(super(InputFlux, self).compare(other, name=name))
+        diff_list.extend(
+            super(InputFlux, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._per_a != self._per_a:
-            diff_list.append(name + ".per_a")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._per_a) + ", other=" + str(other._per_a) + ")"
+                )
+                diff_list.append(name + ".per_a" + val_str)
+            else:
+                diff_list.append(name + ".per_a")
         if other._per_t != self._per_t:
-            diff_list.append(name + ".per_t")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._per_t) + ", other=" + str(other._per_t) + ")"
+                )
+                diff_list.append(name + ".per_t" + val_str)
+            else:
+                diff_list.append(name + ".per_t")
         if other._is_antiper_a != self._is_antiper_a:
-            diff_list.append(name + ".is_antiper_a")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_antiper_a)
+                    + ", other="
+                    + str(other._is_antiper_a)
+                    + ")"
+                )
+                diff_list.append(name + ".is_antiper_a" + val_str)
+            else:
+                diff_list.append(name + ".is_antiper_a")
         if other._is_antiper_t != self._is_antiper_t:
-            diff_list.append(name + ".is_antiper_t")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_antiper_t)
+                    + ", other="
+                    + str(other._is_antiper_t)
+                    + ")"
+                )
+                diff_list.append(name + ".is_antiper_t" + val_str)
+            else:
+                diff_list.append(name + ".is_antiper_t")
         if other._B_dict != self._B_dict:
-            diff_list.append(name + ".B_dict")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._B_dict)
+                    + ", other="
+                    + str(other._B_dict)
+                    + ")"
+                )
+                diff_list.append(name + ".B_dict" + val_str)
+            else:
+                diff_list.append(name + ".B_dict")
         if other._unit != self._unit:
-            diff_list.append(name + ".unit")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._unit) + ", other=" + str(other._unit) + ")"
+                )
+                diff_list.append(name + ".unit" + val_str)
+            else:
+                diff_list.append(name + ".unit")
         if not array_equal(other.slice, self.slice):
             diff_list.append(name + ".slice")
         if (other.B_enforced is None and self.B_enforced is not None) or (
@@ -243,7 +312,12 @@ class InputFlux(InputCurrent):
             diff_list.append(name + ".B_enforced None mismatch")
         elif self.B_enforced is not None:
             diff_list.extend(
-                self.B_enforced.compare(other.B_enforced, name=name + ".B_enforced")
+                self.B_enforced.compare(
+                    other.B_enforced,
+                    name=name + ".B_enforced",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
@@ -319,6 +393,97 @@ class InputFlux(InputCurrent):
         InputFlux_dict["__class__"] = "InputFlux"
         return InputFlux_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        per_a_val = self.per_a
+        per_t_val = self.per_t
+        is_antiper_a_val = self.is_antiper_a
+        is_antiper_t_val = self.is_antiper_t
+        if self.B_dict is None:
+            B_dict_val = None
+        else:
+            B_dict_val = self.B_dict.copy()
+        unit_val = self.unit
+        if self.slice is None:
+            slice_val = None
+        else:
+            slice_val = self.slice.copy()
+        if self.B_enforced is None:
+            B_enforced_val = None
+        else:
+            B_enforced_val = self.B_enforced.copy()
+        if self.Is is None:
+            Is_val = None
+        else:
+            Is_val = self.Is.copy()
+        if self.Ir is None:
+            Ir_val = None
+        else:
+            Ir_val = self.Ir.copy()
+        if self.Is_harm is None:
+            Is_harm_val = None
+        else:
+            Is_harm_val = self.Is_harm.copy()
+        rot_dir_val = self.rot_dir
+        angle_rotor_initial_val = self.angle_rotor_initial
+        if self.PWM is None:
+            PWM_val = None
+        else:
+            PWM_val = self.PWM.copy()
+        phase_dir_val = self.phase_dir
+        current_dir_val = self.current_dir
+        is_periodicity_t_val = self.is_periodicity_t
+        is_periodicity_a_val = self.is_periodicity_a
+        is_generator_val = self.is_generator
+        if self.time is None:
+            time_val = None
+        else:
+            time_val = self.time.copy()
+        if self.angle is None:
+            angle_val = None
+        else:
+            angle_val = self.angle.copy()
+        Nt_tot_val = self.Nt_tot
+        Nrev_val = self.Nrev
+        Na_tot_val = self.Na_tot
+        if self.OP is None:
+            OP_val = None
+        else:
+            OP_val = self.OP.copy()
+        t_final_val = self.t_final
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            per_a=per_a_val,
+            per_t=per_t_val,
+            is_antiper_a=is_antiper_a_val,
+            is_antiper_t=is_antiper_t_val,
+            B_dict=B_dict_val,
+            unit=unit_val,
+            slice=slice_val,
+            B_enforced=B_enforced_val,
+            Is=Is_val,
+            Ir=Ir_val,
+            Is_harm=Is_harm_val,
+            rot_dir=rot_dir_val,
+            angle_rotor_initial=angle_rotor_initial_val,
+            PWM=PWM_val,
+            phase_dir=phase_dir_val,
+            current_dir=current_dir_val,
+            is_periodicity_t=is_periodicity_t_val,
+            is_periodicity_a=is_periodicity_a_val,
+            is_generator=is_generator_val,
+            time=time_val,
+            angle=angle_val,
+            Nt_tot=Nt_tot_val,
+            Nrev=Nrev_val,
+            Na_tot=Na_tot_val,
+            OP=OP_val,
+            t_final=t_final_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -475,7 +640,13 @@ class InputFlux(InputCurrent):
     def _set_B_enforced(self, value):
         """setter of B_enforced"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "SciDataTool.Classes", value.get("__class__"), "B_enforced"
