@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -33,8 +33,8 @@ except ImportError as error:
     remove_model = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .LossModel import LossModel
 
 
 class Loss(FrozenClass):
@@ -68,9 +68,8 @@ class Loss(FrozenClass):
         )
     else:
         remove_model = remove_model
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -79,6 +78,7 @@ class Loss(FrozenClass):
         model_index=-1,
         model_list=-1,
         logger_name="Pyleecan.Loss",
+        model_dict=None,
         init_dict=None,
         init_str=None,
     ):
@@ -103,11 +103,14 @@ class Loss(FrozenClass):
                 model_list = init_dict["model_list"]
             if "logger_name" in list(init_dict.keys()):
                 logger_name = init_dict["logger_name"]
+            if "model_dict" in list(init_dict.keys()):
+                model_dict = init_dict["model_dict"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.model_index = model_index
         self.model_list = model_list
         self.logger_name = logger_name
+        self.model_dict = model_dict
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -129,6 +132,14 @@ class Loss(FrozenClass):
             )
             Loss_str += "model_list[" + str(ii) + "] =" + tmp + linesep + linesep
         Loss_str += 'logger_name = "' + str(self.logger_name) + '"' + linesep
+        if len(self.model_dict) == 0:
+            Loss_str += "model_dict = dict()" + linesep
+        for key, obj in self.model_dict.items():
+            tmp = (
+                self.model_dict[key].__str__().replace(linesep, linesep + "\t")
+                + linesep
+            )
+            Loss_str += "model_dict[" + key + "] =" + tmp + linesep + linesep
         return Loss_str
 
     def __eq__(self, other):
@@ -142,9 +153,11 @@ class Loss(FrozenClass):
             return False
         if other.logger_name != self.logger_name:
             return False
+        if other.model_dict != self.model_dict:
+            return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -153,7 +166,17 @@ class Loss(FrozenClass):
             return ["type(" + name + ")"]
         diff_list = list()
         if other._model_index != self._model_index:
-            diff_list.append(name + ".model_index")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._model_index)
+                    + ", other="
+                    + str(other._model_index)
+                    + ")"
+                )
+                diff_list.append(name + ".model_index" + val_str)
+            else:
+                diff_list.append(name + ".model_index")
         if (other.model_list is None and self.model_list is not None) or (
             other.model_list is not None and self.model_list is None
         ):
@@ -166,11 +189,42 @@ class Loss(FrozenClass):
             for ii in range(len(other.model_list)):
                 diff_list.extend(
                     self.model_list[ii].compare(
-                        other.model_list[ii], name=name + ".model_list[" + str(ii) + "]"
+                        other.model_list[ii],
+                        name=name + ".model_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if other._logger_name != self._logger_name:
-            diff_list.append(name + ".logger_name")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._logger_name)
+                    + ", other="
+                    + str(other._logger_name)
+                    + ")"
+                )
+                diff_list.append(name + ".logger_name" + val_str)
+            else:
+                diff_list.append(name + ".logger_name")
+        if (other.model_dict is None and self.model_dict is not None) or (
+            other.model_dict is not None and self.model_dict is None
+        ):
+            diff_list.append(name + ".model_dict None mismatch")
+        elif self.model_dict is None:
+            pass
+        elif len(other.model_dict) != len(self.model_dict):
+            diff_list.append("len(" + name + "model_dict)")
+        else:
+            for key in self.model_dict:
+                diff_list.extend(
+                    self.model_dict[key].compare(
+                        other.model_dict[key],
+                        name=name + ".model_dict[" + str(key) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
+                    )
+                )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -186,6 +240,9 @@ class Loss(FrozenClass):
             for value in self.model_list:
                 S += getsizeof(value)
         S += getsizeof(self.logger_name)
+        if self.model_dict is not None:
+            for key, value in self.model_dict.items():
+                S += getsizeof(value) + getsizeof(key)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -219,16 +276,60 @@ class Loss(FrozenClass):
                 else:
                     Loss_dict["model_list"].append(None)
         Loss_dict["logger_name"] = self.logger_name
+        if self.model_dict is None:
+            Loss_dict["model_dict"] = None
+        else:
+            Loss_dict["model_dict"] = dict()
+            for key, obj in self.model_dict.items():
+                if obj is not None:
+                    Loss_dict["model_dict"][key] = obj.as_dict(
+                        type_handle_ndarray=type_handle_ndarray,
+                        keep_function=keep_function,
+                        **kwargs
+                    )
+                else:
+                    Loss_dict["model_dict"][key] = None
         # The class name is added to the dict for deserialisation purpose
         Loss_dict["__class__"] = "Loss"
         return Loss_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.model_index is None:
+            model_index_val = None
+        else:
+            model_index_val = self.model_index.copy()
+        if self.model_list is None:
+            model_list_val = None
+        else:
+            model_list_val = list()
+            for obj in self.model_list:
+                model_list_val.append(obj.copy())
+        logger_name_val = self.logger_name
+        if self.model_dict is None:
+            model_dict_val = None
+        else:
+            model_dict_val = dict()
+            for key, obj in self.model_dict.items():
+                model_dict_val[key] = obj.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            model_index=model_index_val,
+            model_list=model_list_val,
+            logger_name=logger_name_val,
+            model_dict=model_dict_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
         self.model_index = None
         self.model_list = None
         self.logger_name = None
+        self.model_dict = None
 
     def _get_model_index(self):
         """getter of model_index"""
@@ -244,7 +345,7 @@ class Loss(FrozenClass):
     model_index = property(
         fget=_get_model_index,
         fset=_set_model_index,
-        doc=u"""Internal dict to strore model index
+        doc=u"""Internal dict to store model index
 
         :Type: dict
         """,
@@ -262,6 +363,15 @@ class Loss(FrozenClass):
         """setter of model_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "model_list"
@@ -300,3 +410,43 @@ class Loss(FrozenClass):
         :Type: str
         """,
     )
+
+    def _get_model_dict(self):
+        """getter of model_dict"""
+        if self._model_dict is not None:
+            for key, obj in self._model_dict.items():
+                if obj is not None:
+                    obj.parent = self
+        return self._model_dict
+
+    def _set_model_dict(self, value):
+        """setter of model_dict"""
+        if type(value) is dict:
+            for key, obj in value.items():
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[key] = None
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "pyleecan.Classes", obj.get("__class__"), "model_dict"
+                    )
+                    value[key] = class_obj(init_dict=obj)
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("model_dict", value, "{LossModel}")
+        self._model_dict = value
+
+    model_dict = property(
+        fget=_get_model_dict,
+        fset=_set_model_dict,
+        doc=u"""Dict of loss model whose key is a lamination and value is the associated loss model (alternative to model_index/model_list)
+
+        :Type: {LossModel}
+        """,
+    )
