@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Machine import Machine
 
 # Import all class method
@@ -28,9 +28,8 @@ except ImportError as error:
     comp_desc_dict = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Frame import Frame
-from .Shaft import Shaft
 
 
 class MachineAsync(Machine):
@@ -63,9 +62,8 @@ class MachineAsync(Machine):
         )
     else:
         comp_desc_dict = comp_desc_dict
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -139,7 +137,7 @@ class MachineAsync(Machine):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -149,7 +147,11 @@ class MachineAsync(Machine):
         diff_list = list()
 
         # Check the properties inherited from Machine
-        diff_list.extend(super(MachineAsync, self).compare(other, name=name))
+        diff_list.extend(
+            super(MachineAsync, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -185,6 +187,33 @@ class MachineAsync(Machine):
         MachineAsync_dict["__class__"] = "MachineAsync"
         return MachineAsync_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.frame is None:
+            frame_val = None
+        else:
+            frame_val = self.frame.copy()
+        if self.shaft is None:
+            shaft_val = None
+        else:
+            shaft_val = self.shaft.copy()
+        name_val = self.name
+        desc_val = self.desc
+        type_machine_val = self.type_machine
+        logger_name_val = self.logger_name
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            frame=frame_val,
+            shaft=shaft_val,
+            name=name_val,
+            desc=desc_val,
+            type_machine=type_machine_val,
+            logger_name=logger_name_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
