@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Machine import Machine
 
 # Import all class method
@@ -28,10 +28,8 @@ except ImportError as error:
     is_synchronous = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Lamination import Lamination
-from .Frame import Frame
-from .Shaft import Shaft
 
 
 class MachineUD(Machine):
@@ -62,9 +60,8 @@ class MachineUD(Machine):
         )
     else:
         is_synchronous = is_synchronous
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -156,7 +153,7 @@ class MachineUD(Machine):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -166,7 +163,11 @@ class MachineUD(Machine):
         diff_list = list()
 
         # Check the properties inherited from Machine
-        diff_list.extend(super(MachineUD, self).compare(other, name=name))
+        diff_list.extend(
+            super(MachineUD, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if (other.lam_list is None and self.lam_list is not None) or (
             other.lam_list is not None and self.lam_list is None
         ):
@@ -179,11 +180,24 @@ class MachineUD(Machine):
             for ii in range(len(other.lam_list)):
                 diff_list.extend(
                     self.lam_list[ii].compare(
-                        other.lam_list[ii], name=name + ".lam_list[" + str(ii) + "]"
+                        other.lam_list[ii],
+                        name=name + ".lam_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if other._is_sync != self._is_sync:
-            diff_list.append(name + ".is_sync")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_sync)
+                    + ", other="
+                    + str(other._is_sync)
+                    + ")"
+                )
+                diff_list.append(name + ".is_sync" + val_str)
+            else:
+                diff_list.append(name + ".is_sync")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -239,6 +253,42 @@ class MachineUD(Machine):
         MachineUD_dict["__class__"] = "MachineUD"
         return MachineUD_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.lam_list is None:
+            lam_list_val = None
+        else:
+            lam_list_val = list()
+            for obj in self.lam_list:
+                lam_list_val.append(obj.copy())
+        is_sync_val = self.is_sync
+        if self.frame is None:
+            frame_val = None
+        else:
+            frame_val = self.frame.copy()
+        if self.shaft is None:
+            shaft_val = None
+        else:
+            shaft_val = self.shaft.copy()
+        name_val = self.name
+        desc_val = self.desc
+        type_machine_val = self.type_machine
+        logger_name_val = self.logger_name
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            lam_list=lam_list_val,
+            is_sync=is_sync_val,
+            frame=frame_val,
+            shaft=shaft_val,
+            name=name_val,
+            desc=desc_val,
+            type_machine=type_machine_val,
+            logger_name=logger_name_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -259,6 +309,15 @@ class MachineUD(Machine):
         """setter of lam_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "lam_list"
