@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Post import Post
 
 # Import all class method
@@ -23,6 +23,7 @@ except ImportError as error:
     run = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -40,9 +41,8 @@ class PostMethod(Post):
         )
     else:
         run = run
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -87,7 +87,7 @@ class PostMethod(Post):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -97,7 +97,11 @@ class PostMethod(Post):
         diff_list = list()
 
         # Check the properties inherited from Post
-        diff_list.extend(super(PostMethod, self).compare(other, name=name))
+        diff_list.extend(
+            super(PostMethod, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -133,6 +137,14 @@ class PostMethod(Post):
         PostMethod_dict["__class__"] = "PostMethod"
         return PostMethod_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)()
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
