@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Line import Line
 
 # Import all class method
@@ -102,7 +102,23 @@ try:
 except ImportError as error:
     translate = error
 
+try:
+    from ..Methods.Geometry.Segment.split_point import split_point
+except ImportError as error:
+    split_point = error
 
+try:
+    from ..Methods.Geometry.Segment.intersect_obj import intersect_obj
+except ImportError as error:
+    intersect_obj = error
+
+try:
+    from ..Methods.Geometry.Segment.is_arc import is_arc
+except ImportError as error:
+    is_arc = error
+
+
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -269,9 +285,37 @@ class Segment(Line):
         )
     else:
         translate = translate
-    # save and copy methods are available in all object
+    # cf Methods.Geometry.Segment.split_point
+    if isinstance(split_point, ImportError):
+        split_point = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use Segment method split_point: " + str(split_point))
+            )
+        )
+    else:
+        split_point = split_point
+    # cf Methods.Geometry.Segment.intersect_obj
+    if isinstance(intersect_obj, ImportError):
+        intersect_obj = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Segment method intersect_obj: " + str(intersect_obj)
+                )
+            )
+        )
+    else:
+        intersect_obj = intersect_obj
+    # cf Methods.Geometry.Segment.is_arc
+    if isinstance(is_arc, ImportError):
+        is_arc = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use Segment method is_arc: " + str(is_arc))
+            )
+        )
+    else:
+        is_arc = is_arc
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -330,7 +374,7 @@ class Segment(Line):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -340,11 +384,27 @@ class Segment(Line):
         diff_list = list()
 
         # Check the properties inherited from Line
-        diff_list.extend(super(Segment, self).compare(other, name=name))
+        diff_list.extend(
+            super(Segment, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._begin != self._begin:
-            diff_list.append(name + ".begin")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._begin) + ", other=" + str(other._begin) + ")"
+                )
+                diff_list.append(name + ".begin" + val_str)
+            else:
+                diff_list.append(name + ".begin")
         if other._end != self._end:
-            diff_list.append(name + ".end")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._end) + ", other=" + str(other._end) + ")"
+                )
+                diff_list.append(name + ".end" + val_str)
+            else:
+                diff_list.append(name + ".end")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -394,6 +454,20 @@ class Segment(Line):
         Segment_dict["__class__"] = "Segment"
         return Segment_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        begin_val = self.begin
+        end_val = self.end
+        if self.prop_dict is None:
+            prop_dict_val = None
+        else:
+            prop_dict_val = self.prop_dict.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(begin=begin_val, end=end_val, prop_dict=prop_dict_val)
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
