@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Slot import Slot
 
 # Import all class method
@@ -23,9 +23,9 @@ except ImportError as error:
     build_geometry = error
 
 try:
-    from ..Methods.Slot.SlotUD.set_from_point_list import set_from_point_list
+    from ..Methods.Slot.SlotUD.check import check
 except ImportError as error:
-    set_from_point_list = error
+    check = error
 
 try:
     from ..Methods.Slot.SlotUD.get_surface_active import get_surface_active
@@ -33,13 +33,18 @@ except ImportError as error:
     get_surface_active = error
 
 try:
-    from ..Methods.Slot.SlotUD.check import check
+    from ..Methods.Slot.SlotUD.get_surface_opening import get_surface_opening
 except ImportError as error:
-    check = error
+    get_surface_opening = error
+
+try:
+    from ..Methods.Slot.SlotUD.set_from_point_list import set_from_point_list
+except ImportError as error:
+    set_from_point_list = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Line import Line
 
 
 class SlotUD(Slot):
@@ -59,18 +64,15 @@ class SlotUD(Slot):
         )
     else:
         build_geometry = build_geometry
-    # cf Methods.Slot.SlotUD.set_from_point_list
-    if isinstance(set_from_point_list, ImportError):
-        set_from_point_list = property(
+    # cf Methods.Slot.SlotUD.check
+    if isinstance(check, ImportError):
+        check = property(
             fget=lambda x: raise_(
-                ImportError(
-                    "Can't use SlotUD method set_from_point_list: "
-                    + str(set_from_point_list)
-                )
+                ImportError("Can't use SlotUD method check: " + str(check))
             )
         )
     else:
-        set_from_point_list = set_from_point_list
+        check = check
     # cf Methods.Slot.SlotUD.get_surface_active
     if isinstance(get_surface_active, ImportError):
         get_surface_active = property(
@@ -83,18 +85,32 @@ class SlotUD(Slot):
         )
     else:
         get_surface_active = get_surface_active
-    # cf Methods.Slot.SlotUD.check
-    if isinstance(check, ImportError):
-        check = property(
+    # cf Methods.Slot.SlotUD.get_surface_opening
+    if isinstance(get_surface_opening, ImportError):
+        get_surface_opening = property(
             fget=lambda x: raise_(
-                ImportError("Can't use SlotUD method check: " + str(check))
+                ImportError(
+                    "Can't use SlotUD method get_surface_opening: "
+                    + str(get_surface_opening)
+                )
             )
         )
     else:
-        check = check
-    # save and copy methods are available in all object
+        get_surface_opening = get_surface_opening
+    # cf Methods.Slot.SlotUD.set_from_point_list
+    if isinstance(set_from_point_list, ImportError):
+        set_from_point_list = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotUD method set_from_point_list: "
+                    + str(set_from_point_list)
+                )
+            )
+        )
+    else:
+        set_from_point_list = set_from_point_list
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -106,6 +122,8 @@ class SlotUD(Slot):
         type_line_wind=0,
         name="",
         Zs=36,
+        wedge_mat=None,
+        is_bore=True,
         init_dict=None,
         init_str=None,
     ):
@@ -136,6 +154,10 @@ class SlotUD(Slot):
                 name = init_dict["name"]
             if "Zs" in list(init_dict.keys()):
                 Zs = init_dict["Zs"]
+            if "wedge_mat" in list(init_dict.keys()):
+                wedge_mat = init_dict["wedge_mat"]
+            if "is_bore" in list(init_dict.keys()):
+                is_bore = init_dict["is_bore"]
         # Set the properties (value check and convertion are done in setter)
         self.line_list = line_list
         self.wind_begin_index = wind_begin_index
@@ -143,7 +165,7 @@ class SlotUD(Slot):
         self.type_line_wind = type_line_wind
         self.name = name
         # Call Slot init
-        super(SlotUD, self).__init__(Zs=Zs)
+        super(SlotUD, self).__init__(Zs=Zs, wedge_mat=wedge_mat, is_bore=is_bore)
         # The class is frozen (in Slot init), for now it's impossible to
         # add new properties
 
@@ -187,7 +209,7 @@ class SlotUD(Slot):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -197,7 +219,11 @@ class SlotUD(Slot):
         diff_list = list()
 
         # Check the properties inherited from Slot
-        diff_list.extend(super(SlotUD, self).compare(other, name=name))
+        diff_list.extend(
+            super(SlotUD, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if (other.line_list is None and self.line_list is not None) or (
             other.line_list is not None and self.line_list is None
         ):
@@ -210,17 +236,56 @@ class SlotUD(Slot):
             for ii in range(len(other.line_list)):
                 diff_list.extend(
                     self.line_list[ii].compare(
-                        other.line_list[ii], name=name + ".line_list[" + str(ii) + "]"
+                        other.line_list[ii],
+                        name=name + ".line_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if other._wind_begin_index != self._wind_begin_index:
-            diff_list.append(name + ".wind_begin_index")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._wind_begin_index)
+                    + ", other="
+                    + str(other._wind_begin_index)
+                    + ")"
+                )
+                diff_list.append(name + ".wind_begin_index" + val_str)
+            else:
+                diff_list.append(name + ".wind_begin_index")
         if other._wind_end_index != self._wind_end_index:
-            diff_list.append(name + ".wind_end_index")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._wind_end_index)
+                    + ", other="
+                    + str(other._wind_end_index)
+                    + ")"
+                )
+                diff_list.append(name + ".wind_end_index" + val_str)
+            else:
+                diff_list.append(name + ".wind_end_index")
         if other._type_line_wind != self._type_line_wind:
-            diff_list.append(name + ".type_line_wind")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._type_line_wind)
+                    + ", other="
+                    + str(other._type_line_wind)
+                    + ")"
+                )
+                diff_list.append(name + ".type_line_wind" + val_str)
+            else:
+                diff_list.append(name + ".type_line_wind")
         if other._name != self._name:
-            diff_list.append(name + ".name")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._name) + ", other=" + str(other._name) + ")"
+                )
+                diff_list.append(name + ".name" + val_str)
+            else:
+                diff_list.append(name + ".name")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -282,6 +347,39 @@ class SlotUD(Slot):
         SlotUD_dict["__class__"] = "SlotUD"
         return SlotUD_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.line_list is None:
+            line_list_val = None
+        else:
+            line_list_val = list()
+            for obj in self.line_list:
+                line_list_val.append(obj.copy())
+        wind_begin_index_val = self.wind_begin_index
+        wind_end_index_val = self.wind_end_index
+        type_line_wind_val = self.type_line_wind
+        name_val = self.name
+        Zs_val = self.Zs
+        if self.wedge_mat is None:
+            wedge_mat_val = None
+        else:
+            wedge_mat_val = self.wedge_mat.copy()
+        is_bore_val = self.is_bore
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            line_list=line_list_val,
+            wind_begin_index=wind_begin_index_val,
+            wind_end_index=wind_end_index_val,
+            type_line_wind=type_line_wind_val,
+            name=name_val,
+            Zs=Zs_val,
+            wedge_mat=wedge_mat_val,
+            is_bore=is_bore_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -305,6 +403,15 @@ class SlotUD(Slot):
         """setter of line_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "line_list"
