@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Slot import Slot
 
 # Import all class method
@@ -68,6 +68,7 @@ except ImportError as error:
     plot_schematics = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -193,9 +194,8 @@ class SlotWLSRPM(Slot):
         )
     else:
         plot_schematics = plot_schematics
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -207,6 +207,8 @@ class SlotWLSRPM(Slot):
         R1=0.00075,
         H3=0.001,
         Zs=36,
+        wedge_mat=None,
+        is_bore=True,
         init_dict=None,
         init_str=None,
     ):
@@ -237,6 +239,10 @@ class SlotWLSRPM(Slot):
                 H3 = init_dict["H3"]
             if "Zs" in list(init_dict.keys()):
                 Zs = init_dict["Zs"]
+            if "wedge_mat" in list(init_dict.keys()):
+                wedge_mat = init_dict["wedge_mat"]
+            if "is_bore" in list(init_dict.keys()):
+                is_bore = init_dict["is_bore"]
         # Set the properties (value check and convertion are done in setter)
         self.W1 = W1
         self.W3 = W3
@@ -244,7 +250,7 @@ class SlotWLSRPM(Slot):
         self.R1 = R1
         self.H3 = H3
         # Call Slot init
-        super(SlotWLSRPM, self).__init__(Zs=Zs)
+        super(SlotWLSRPM, self).__init__(Zs=Zs, wedge_mat=wedge_mat, is_bore=is_bore)
         # The class is frozen (in Slot init), for now it's impossible to
         # add new properties
 
@@ -282,7 +288,7 @@ class SlotWLSRPM(Slot):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -292,17 +298,76 @@ class SlotWLSRPM(Slot):
         diff_list = list()
 
         # Check the properties inherited from Slot
-        diff_list.extend(super(SlotWLSRPM, self).compare(other, name=name))
-        if other._W1 != self._W1:
-            diff_list.append(name + ".W1")
-        if other._W3 != self._W3:
-            diff_list.append(name + ".W3")
-        if other._H2 != self._H2:
-            diff_list.append(name + ".H2")
-        if other._R1 != self._R1:
-            diff_list.append(name + ".R1")
-        if other._H3 != self._H3:
-            diff_list.append(name + ".H3")
+        diff_list.extend(
+            super(SlotWLSRPM, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
+        if (
+            other._W1 is not None
+            and self._W1 is not None
+            and isnan(other._W1)
+            and isnan(self._W1)
+        ):
+            pass
+        elif other._W1 != self._W1:
+            if is_add_value:
+                val_str = " (self=" + str(self._W1) + ", other=" + str(other._W1) + ")"
+                diff_list.append(name + ".W1" + val_str)
+            else:
+                diff_list.append(name + ".W1")
+        if (
+            other._W3 is not None
+            and self._W3 is not None
+            and isnan(other._W3)
+            and isnan(self._W3)
+        ):
+            pass
+        elif other._W3 != self._W3:
+            if is_add_value:
+                val_str = " (self=" + str(self._W3) + ", other=" + str(other._W3) + ")"
+                diff_list.append(name + ".W3" + val_str)
+            else:
+                diff_list.append(name + ".W3")
+        if (
+            other._H2 is not None
+            and self._H2 is not None
+            and isnan(other._H2)
+            and isnan(self._H2)
+        ):
+            pass
+        elif other._H2 != self._H2:
+            if is_add_value:
+                val_str = " (self=" + str(self._H2) + ", other=" + str(other._H2) + ")"
+                diff_list.append(name + ".H2" + val_str)
+            else:
+                diff_list.append(name + ".H2")
+        if (
+            other._R1 is not None
+            and self._R1 is not None
+            and isnan(other._R1)
+            and isnan(self._R1)
+        ):
+            pass
+        elif other._R1 != self._R1:
+            if is_add_value:
+                val_str = " (self=" + str(self._R1) + ", other=" + str(other._R1) + ")"
+                diff_list.append(name + ".R1" + val_str)
+            else:
+                diff_list.append(name + ".R1")
+        if (
+            other._H3 is not None
+            and self._H3 is not None
+            and isnan(other._H3)
+            and isnan(self._H3)
+        ):
+            pass
+        elif other._H3 != self._H3:
+            if is_add_value:
+                val_str = " (self=" + str(self._H3) + ", other=" + str(other._H3) + ")"
+                diff_list.append(name + ".H3" + val_str)
+            else:
+                diff_list.append(name + ".H3")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -348,6 +413,34 @@ class SlotWLSRPM(Slot):
         SlotWLSRPM_dict["__class__"] = "SlotWLSRPM"
         return SlotWLSRPM_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        W1_val = self.W1
+        W3_val = self.W3
+        H2_val = self.H2
+        R1_val = self.R1
+        H3_val = self.H3
+        Zs_val = self.Zs
+        if self.wedge_mat is None:
+            wedge_mat_val = None
+        else:
+            wedge_mat_val = self.wedge_mat.copy()
+        is_bore_val = self.is_bore
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            W1=W1_val,
+            W3=W3_val,
+            H2=H2_val,
+            R1=R1_val,
+            H3=H3_val,
+            Zs=Zs_val,
+            wedge_mat=wedge_mat_val,
+            is_bore=is_bore_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
