@@ -1,7 +1,8 @@
 from numpy import angle, pi, floor_divide
-
-from ...Methods import NotImplementedYetError
+from ...Classes.LamHole import LamHole
+from ...Classes.LamHoleNS import LamHoleNS
 from ...Functions.FEMM.get_mesh_param import get_mesh_param
+from ...Methods import NotImplementedYetError
 from ...Functions.Winding.find_wind_phase_color import get_phase_id
 from ...Functions.labels import (
     decode_label,
@@ -30,6 +31,7 @@ def assign_FEMM_surface(femm, surf, prop, FEMM_dict, machine):
         dictionary containing the main parameters of FEMM
     machine : Machine
         Machine to draw
+
     Returns
     -------
     None
@@ -40,6 +42,8 @@ def assign_FEMM_surface(femm, surf, prop, FEMM_dict, machine):
     label_dict = decode_label(label)
     mesh_dict = get_mesh_param(label_dict, FEMM_dict)
 
+    group = mesh_dict["group"]
+
     Clabel = 0  # By default no circuit
     Ntcoil = 0  # By default no circuit
     mag = 0  # By default no magnetization
@@ -68,11 +72,13 @@ def assign_FEMM_surface(femm, surf, prop, FEMM_dict, machine):
             Ntcoil = wind_mat[Nrad_id, Ntan_id, Zs_id, q_id]
         elif HOLEM_LAB in label_dict["surf_type"]:  # LamHole
             mag_obj = get_obj_from_label(machine, label_dict=label_dict)
-            if mag_obj.type_magnetization in [1, 3, None]:  # Parallel or Tangential
+            # Parallel (default) or Tangential
+            if mag_obj.type_magnetization in [1, 3, None]:
                 # calculate pole angle and angle of pole middle
                 T_id = label_dict["T_id"]
                 hole = mag_obj.parent
                 Zh = hole.Zh
+                lam = hole.parent
                 alpha_p = 360 / Zh
                 mag_0 = (
                     floor_divide(angle(point_ref, deg=True), alpha_p) + 0.5
@@ -82,16 +88,34 @@ def assign_FEMM_surface(femm, surf, prop, FEMM_dict, machine):
                 mag = mag_0 + mag_dict["magnet_" + str(T_id)] * 180 / pi
 
                 # modifiy magnetisation of south poles
-                if (label_dict["S_id"] % 2) == 1:
-                    mag = mag + 180
-                if mag_obj.type_magnetization == 3:  # Tangential
+                if isinstance(lam, LamHole):
+                    if (label_dict["S_id"] % 2) == 1:
+                        mag = mag + 180
+                elif isinstance(lam, LamHoleNS):
+                    if hole in lam.hole_south:
+                        mag = mag + 180
+                # Modify magnetisation for Tangential
+                if mag_obj.type_magnetization == 3:
                     mag = mag - 90
+
+                # Assign magnet group
+                nb_hole = int(len(machine.rotor.get_hole_list()))
+                nb_mag_per_hole = machine.rotor.get_magnet_number(
+                    sym=machine.rotor.get_Zs()
+                )
+                grp_id = (
+                    label_dict["S_id"] * nb_hole * nb_mag_per_hole + label_dict["T_id"]
+                )
+                group = group[grp_id]
+
             else:
                 raise NotImplementedYetError(
-                    "Only parallele magnetization are available for HoleMagnet"
+                    "Only parallele magnetization are available for HoleMagnet found: "
+                    + label
                 )
         elif MAG_LAB in label_dict["surf_type"]:  # LamSlotMag
             mag_obj = get_obj_from_label(machine, label_dict=label_dict)
+
             # type_magnetization: 0 for radial, 1 for parallel, 2 for Hallbach
             if mag_obj.type_magnetization == 0 and (label_dict["S_id"] % 2) == 0:
                 mag = "theta"  # Radial North pole magnet
@@ -111,12 +135,17 @@ def assign_FEMM_surface(femm, surf, prop, FEMM_dict, machine):
                 mag = (
                     angle(point_ref) * 180 / pi + 180 - 90
                 )  # Tangential South pole magnet
+
+            # Assign magnet group (assuming one magnet per pole)
+            group = group[label_dict["S_id"]]
+
         elif VENT_LAB in label_dict["surf_type"]:
             vent_obj = get_obj_from_label(machine, label_dict=label_dict)
             prop = "Air"
         elif HOLEV_LAB in label_dict["surf_type"]:
             hole_obj = get_obj_from_label(machine, label_dict=label_dict)
             prop = "Air"
+
         # Set the surface property
         femm.mi_setblockprop(
             prop,
@@ -124,7 +153,7 @@ def assign_FEMM_surface(femm, surf, prop, FEMM_dict, machine):
             mesh_dict["meshsize"],
             Clabel,
             mag,
-            mesh_dict["group"],
+            group,
             Ntcoil,
         )
         femm.mi_clearselected()
