@@ -8,7 +8,6 @@ from ......Classes.HoleM57 import HoleM57
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleM57.Gen_PHoleM57 import Gen_PHoleM57
 from ......Methods.Slot.Slot import SlotCheckError
-from ......GUI.Dialog.DMatLib.MatLib import MatLib
 
 
 class PHoleM57(Gen_PHoleM57, QWidget):
@@ -20,7 +19,7 @@ class PHoleM57(Gen_PHoleM57, QWidget):
     hole_name = "Hole Type 57"
     hole_type = HoleM57
 
-    def __init__(self, hole=None, matlib=MatLib()):
+    def __init__(self, hole=None, material_dict=None):
         """Initialize the widget according to hole
 
         Parameters
@@ -29,14 +28,14 @@ class PHoleM57(Gen_PHoleM57, QWidget):
             A PHoleM57 widget
         hole : HoleM57
             current hole to edit
-        matlib : list
-            List of available Material
+        material_dict : list
+            Materials dictionary (library + machine)
         """
         # Build the interface according to the .ui file
         QWidget.__init__(self)
         self.setupUi(self)
 
-        self.matlib = matlib
+        self.material_dict = material_dict
         self.hole = hole
 
         # Set FloatEdit unit
@@ -65,14 +64,14 @@ class PHoleM57(Gen_PHoleM57, QWidget):
             self.img_slot.setPixmap(
                 QPixmap(":/images/images/MachineSetup/SMHoleMag/HoleM57_no_mag.png")
             )
-            self.w_mat_0.update(self.hole, "mat_void", self.matlib)
+            self.w_mat_0.update(self.hole, "mat_void", self.material_dict)
             self.w_mat_1.hide()
             self.w_mat_2.hide()
         else:
             # Set current material
-            self.w_mat_0.update(self.hole, "mat_void", self.matlib)
-            self.w_mat_1.update(self.hole.magnet_0, "mat_type", self.matlib)
-            self.w_mat_2.update(self.hole.magnet_1, "mat_type", self.matlib)
+            self.w_mat_0.update(self.hole, "mat_void", self.material_dict)
+            self.w_mat_1.update(self.hole.magnet_0, "mat_type", self.material_dict)
+            self.w_mat_2.update(self.hole.magnet_1, "mat_type", self.material_dict)
 
         # Set unit name (m ou mm)
         self.u = gui_option.unit
