@@ -139,7 +139,7 @@ class SWPole(Ui_SWPole, QWidget):
             self.out_Slot_pitch.setText(
                 sp_txt
                 + "%.4g" % (Slot_pitch)
-                + u" ° ("
+                + " ° ("
                 + "%.4g" % (Slot_pitch_rad)
                 + " rad)"
             )
