@@ -1,10 +1,9 @@
-from matplotlib.pyplot import axis, legend
 from numpy import real, imag
 
 from ....Functions.init_fig import init_fig
 
 
-def plot_lines(self, fig=None):
+def plot_lines(self, fig=None, ax=None):
     """Plot the SurfRing-Contour in a matplotlib fig
     (For plotting unclosed contour, for Polygon use plot method from Surface object)
 
@@ -12,18 +11,22 @@ def plot_lines(self, fig=None):
     ----------
     self : SurfRing
         A SurfRing object
-    fig :
-        if None, open a new fig and plot, else add to the
-        current one (Default value = None)
+    fig : Matplotlib.figure.Figure
+        existing figure to use if None create a new one
+    ax : Matplotlib.axes.Axes object
+        Axis on which to plot the data
 
     Returns
     -------
-    None
+    fig : Matplotlib.figure.Figure
+        Figure containing the plot
+    ax : Matplotlib.axes.Axes object
+        Axis containing the plot
     """
 
-    (fig, axes, patch_leg, label_leg) = init_fig(fig)
-    axes.set_xlabel("(m)")
-    axes.set_ylabel("(m)")
+    (fig, ax, patch_leg, label_leg) = init_fig(fig, ax)
+    ax.set_xlabel("(m)")
+    ax.set_ylabel("(m)")
 
     points = self.out_surf.discretize(10)
     for idx in range(len(points) - 1):
@@ -33,7 +36,7 @@ def plot_lines(self, fig=None):
         y1 = imag(z1)
         x2 = real(z2)
         y2 = imag(z2)
-        axes.plot([x1, x2], [y1, y2], "k")
+        ax.plot([x1, x2], [y1, y2], "k")
 
     points = self.in_surf.discretize(10)
     for idx in range(len(points) - 1):
@@ -43,9 +46,10 @@ def plot_lines(self, fig=None):
         y1 = imag(z1)
         x2 = real(z2)
         y2 = imag(z2)
-        axes.plot([x1, x2], [y1, y2], "k")
+        ax.plot([x1, x2], [y1, y2], "k")
 
     # Axis Setup
-    axis("equal")
+    ax.axis("equal")
 
     fig.show()
+    return fig, ax
