@@ -23,7 +23,9 @@ def comp_surfaces(self):
 
     if self.slot is not None:
         S_dict["Swind"] = self.get_Zs() * self.slot.comp_surface_active()
+        S_dict["Swedge"] = self.get_Zs() * self.slot.comp_surface_wedges()
     else:
         S_dict["Swind"] = 0
+        S_dict["Swedge"] = 0
 
     return S_dict
