@@ -4,7 +4,7 @@ from numpy import pi
 
 
 def comp_length_ring(self):
-    """Computation of the ring length
+    """Computation of the squirrel cage end-ring average perimeter (circumferential length)
 
     Parameters
     ----------
@@ -18,6 +18,7 @@ def comp_length_ring(self):
 
     """
 
+    # calculation of the average radius of the center of the end-ring (distance to z-axis of the electrical machine)
     Rmw = self.slot.comp_radius_mid_active()
 
     return 2 * pi * Rmw
