@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 import matplotlib.pyplot as plt
 from matplotlib.patches import Patch
-from matplotlib.pyplot import axis, legend
+from matplotlib.pyplot import legend
 
 from ....Functions.init_fig import init_fig
 from ....definitions import config_dict
@@ -22,6 +20,8 @@ def plot(
     alpha=0,
     delta=0,
     is_edge_only=False,
+    edgecolor=None,
+    is_add_arrow=False,
     is_show_fig=True,
     save_path=None,
 ):
@@ -45,20 +45,26 @@ def plot(
         Complex value for translation
     is_edge_only: bool
         To plot transparent Patches
+    edgecolor:
+        Color of the edges if is_edge_only=True
     is_show_fig : bool
         To call show at the end of the method
     save_path : str
         full path including folder, name and extension of the file to save if save_path is not None
 
+
     Returns
     -------
-
+    fig : Matplotlib.figure.Figure
+        Figure containing the plot
+    ax : Matplotlib.axes.Axes object
+        Axis containing the plot
     """
     if self.is_stator:
         lam_color = STATOR_COLOR
     else:
         lam_color = ROTOR_COLOR
-    (fig, axes, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
+    (fig, ax, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
 
     surf_list = self.build_geometry(sym=sym, alpha=alpha, delta=delta)
     patches = list()
@@ -66,44 +72,53 @@ def plot(
     # Color Selection for Lamination
     for surf in surf_list:
         if surf.label is not None and "Lamination" in surf.label:
-            patches.extend(surf.get_patches(color=lam_color, is_edge_only=is_edge_only))
+            patches.extend(
+                surf.get_patches(
+                    color=lam_color, is_edge_only=is_edge_only, edgecolor=edgecolor
+                )
+            )
         elif surf.label is not None and "Ventilation_" in surf.label:
             patches.extend(
                 surf.get_patches(
-                    color=VENT_COLOR, edgecolor=VENT_EDGE, is_edge_only=is_edge_only
+                    color=VENT_COLOR, edgecolor=edgecolor, is_edge_only=is_edge_only
                 )
             )
         else:
-            patches.extend(surf.get_patches(is_edge_only=is_edge_only))
+            patches.extend(
+                surf.get_patches(is_edge_only=is_edge_only, edgecolor=edgecolor)
+            )
 
     # Display the result
-    axes.set_xlabel("(m)")
-    axes.set_ylabel("(m)")
+    ax.set_xlabel("(m)")
+    ax.set_ylabel("(m)")
     for patch in patches:
-        axes.add_patch(patch)
+        ax.add_patch(patch)
 
     # Axis Setup
-    axes.axis("equal")
+    ax.axis("equal")
 
     # The Lamination is centered in the figure
     Lim = self.Rext * 1.5
-    axes.set_xlim(-Lim, Lim)
-    axes.set_ylim(-Lim, Lim)
+    ax.set_xlim(-Lim, Lim)
+    ax.set_ylim(-Lim, Lim)
+
+    title = None
 
     # Adding legend
     if not is_edge_only:
         if self.is_stator:
             patch_leg.append(Patch(color=STATOR_COLOR))
             label_leg.append("Stator")
-            axes.set_title("Stator without slot")
+            title = "Stator without slot"
         else:
             patch_leg.append(Patch(color=ROTOR_COLOR))
             label_leg.append("Rotor")
-            axes.set_title("Rotor without slot")
-
-        legend(patch_leg, label_leg)
+            title = "Rotor without slot"
+        ax.set_title(title)
+        ax.legend(patch_leg, label_leg)
     if is_show_fig:
         fig.show()
     if save_path is not None:
         fig.savefig(save_path)
-        plt.close()
+        plt.close(fig=fig)
+    return fig, ax
