@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-
 from matplotlib.patches import Patch
-from matplotlib.pyplot import axis, legend
 
 from ....Functions.init_fig import init_fig
 from ....definitions import config_dict
@@ -17,6 +14,7 @@ def plot(
     alpha=0,
     delta=0,
     is_edge_only=False,
+    edgecolor=None,
     is_show_fig=True,
 ):
     """Plot the Shaft in a matplotlib fig
@@ -37,37 +35,47 @@ def plot(
         Complex value for translation
     is_edge_only: bool
         To plot transparent Patches
+    edgecolor:
+        Color of the edges if is_edge_only=True
     is_show_fig : bool
         To call show at the end of the method
 
     Returns
     -------
-    None
+    fig : Matplotlib.figure.Figure
+        Figure containing the plot
+    ax : Matplotlib.axes.Axes object
+        Axis containing the plot
     """
 
-    (fig, axes, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
+    (fig, ax, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
     # Get the shaft surface(s)
     surf_list = self.build_geometry(sym=sym, alpha=alpha, delta=delta)
     patches = list()
     for surf in surf_list:
-        patches.extend(surf.get_patches(color=SHAFT_COLOR, is_edge_only=is_edge_only))
-    axes.set_xlabel("(m)")
-    axes.set_ylabel("(m)")
-    axes.set_title("Shaft")
+        patches.extend(
+            surf.get_patches(
+                color=SHAFT_COLOR, is_edge_only=is_edge_only, edgecolor=edgecolor
+            )
+        )
+    ax.set_xlabel("(m)")
+    ax.set_ylabel("(m)")
+    ax.set_title("Shaft")
     for patch in patches:
-        axes.add_patch(patch)
-    axis("equal")
+        ax.add_patch(patch)
+    ax.axis("equal")
 
     # The Lamination is centered in the figure
     Lim = self.Drsh * 0.6
-    axes.set_xlim(-Lim, Lim)
-    axes.set_ylim(-Lim, Lim)
+    ax.set_xlim(-Lim, Lim)
+    ax.set_ylim(-Lim, Lim)
 
     # Add legend
     if not is_edge_only:
         patch_leg.append(Patch(color=SHAFT_COLOR))
         label_leg.append("Shaft")
 
-        legend(patch_leg, label_leg)
+        ax.legend(patch_leg, label_leg)
     if is_show_fig:
         fig.show()
+    return fig, ax
