@@ -78,7 +78,7 @@ def comp_connection_mat(self, Zs=None, p=None):
     # Apply the transformations
     if self.is_reverse_wind:
         wind_mat = reverse_wind_mat(wind_mat)
-    if self.Nslot_shift_wind > 0:
+    if self.Nslot_shift_wind != 0:
         wind_mat = shift_wind_mat(wind_mat, self.Nslot_shift_wind)
 
     return wind_mat
