@@ -6,6 +6,7 @@ from SciDataTool.Functions.Plot.plot_2D import plot_2D
 from ....definitions import config_dict
 from ....Methods.Output.XOutput import _get_symbol_data_
 from ....Functions.Plot import dict_2D, dict_3D
+from ....Functions.init_fig import init_fig
 
 COLORS = config_dict["PLOT"]["COLOR_DICT"]["COLOR_LIST"]
 COLORMAP = config_dict["PLOT"]["COLOR_DICT"]["COLOR_MAP"]
@@ -27,15 +28,20 @@ def plot_multi(
     cmap=None,
     plot_type="point",
     idx=None,
+    fig=None,
     ax=None,
     title=None,
     is_show_fig=True,
     save_path=None,
     win_title=None,
 ):
-    """
-    Plot data from a DataKeeper for a given parameter from a ParamExplorer
+    """2D Plot from a DataKeeper / OptiObjective / ParamExplorer as a function of another
+    DataKeeper / OptiObjective / ParamExplorer
 
+    Parameters
+    ----------
+    self : XOutput
+        XOutput object
     x_symbol: str
         ParamExplorer or DataKeeper symbol
     y_symbol: str
@@ -48,18 +54,25 @@ def plot_multi(
         scatter or plot to chose plot type
     idx: slice
         To plot only some data
-    ax: matplotlib.pyplot.Axe
-        To put the plot in a specific ax
+    fig : Matplotlib.figure.Figure
+        existing figure to use if None create a new one
+    ax : Matplotlib.axes.Axes object
+        ax on which to plot the data
     title: str
         Figure or subfigure title according to ax
     is_show_fig : bool
         True to show figure after plot
     save_path : str
         full path of the png file where the figure is saved if save_path is not None
+    win_title : str
+        Title of the plot window
 
     Returns
     -------
-    fig or ax
+    fig : Matplotlib.figure.Figure
+        Figure containing the plot
+    ax : Matplotlib.axes.Axes object
+        Axis containing the plot
 
     Raises
     ------
@@ -92,6 +105,8 @@ def plot_multi(
     if cmap is None:
         cmap = COLORMAP
 
+    (fig, ax, _, _) = init_fig(fig=fig, ax=ax, shape="rectangle")
+
     # call plot_2D function
     plot_2D(
         Xdatas=[x_values],
@@ -105,43 +120,11 @@ def plot_multi(
         save_path=save_path,
         is_show_fig=is_show_fig,
         win_title=win_title,
+        fig=fig,
+        ax=ax,
         font_name=FONT_NAME,
         font_size_title=FONT_SIZE_TITLE,
         font_size_label=FONT_SIZE_LABEL,
         font_size_legend=FONT_SIZE_LEGEND,
     )
-    # RET_FIG = False
-    # if ax is None:
-    #     fig, ax = plt.subplots()
-    #     fig.suptitle(title, fontname=FONT_NAME)
-    #     RET_FIG = True
-    # else:
-    #     ax.set_title(title, fontname=FONT_NAME)
-
-    # # plot
-    # if plot_type == "scatter":
-    #     plot = ax.scatter(x_values, y_values, c=colors)
-    # elif plot_type == "curve":
-    #     sort_index = np.argsort(x_values)
-    #     plot = ax.plot(x_values[sort_index], y_values[sort_index], c=colors)
-
-    # # add legend
-    # if c_symbol is not None:
-    #     legend1 = ax.legend(*plot.legend_elements(), loc="upper right", title=c_symbol)
-    #     ax.add_artist(legend1)
-
-    # ax.set_xlabel(x_label, fontname=FONT_NAME)
-    # ax.set_ylabel(y_label, fontname=FONT_NAME)
-
-    # if save_path is not None:
-    #     fig.savefig(save_path)
-    #     plt.close()
-
-    # if is_show_fig:
-    #     fig.show()
-
-    # # return
-    # if RET_FIG:
-    #     return fig
-    # else:
-    #     return ax
+    return fig, ax
