@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 
-def MagnetIndexError(Exception):
+class MagnetIndexError(Exception):
     """Raise when trying to access a non existing magnet"""
+
     pass
