@@ -33,6 +33,8 @@ def plot_schematics(
     type_add_active=True,
     save_path=None,
     is_show_fig=True,
+    fig=None,
+    ax=None,
 ):
     """Plot the schematics of the slot
 
@@ -40,8 +42,8 @@ def plot_schematics(
     ----------
     self : SlotM10
         A SlotM10 object
-    is_default : bool
-        True: plot default schematics, else use current slot values
+    is_default : int
+        0: current slot values, 1: default internal rotor schematics, 2: default external stator schematics
     is_add_point_label : bool
         True to display the name of the points (Z1, Z2....)
     is_add_schematics : bool
@@ -54,15 +56,31 @@ def plot_schematics(
         full path including folder, name and extension of the file to save if save_path is not None
     is_show_fig : bool
         To call show at the end of the method
+    fig : Matplotlib.figure.Figure
+        existing figure to use if None create a new one
+    ax : Matplotlib.axes.Axes object
+        Axis on which to plot the data
+
+    Returns
+    -------
+    fig : Matplotlib.figure.Figure
+        Figure containing the schematics
+    ax : Matplotlib.axes.Axes object
+        Axis containing the schematics
     """
 
     # Use some default parameter
     if is_default:
         slot = type(self)(Zs=8, H0=20e-3, W0=45e-3, Hmag=17.5e-3, Wmag=30e-3)
-        lam = LamSlot(
-            Rint=0.1, Rext=0.135, is_internal=True, is_stator=False, slot=slot
-        )
-        slot.plot_schematics(
+        if is_default == 1:  # Internal Rotor schematics
+            lam = LamSlot(
+                Rint=0.1, Rext=0.135, is_internal=True, is_stator=False, slot=slot
+            )
+        else:  # External Stator schematics
+            lam = LamSlot(
+                Rint=0.1, Rext=0.135, is_internal=False, is_stator=True, slot=slot
+            )
+        return slot.plot_schematics(
             is_default=False,
             is_add_point_label=is_add_point_label,
             is_add_schematics=is_add_schematics,
@@ -70,15 +88,17 @@ def plot_schematics(
             type_add_active=type_add_active,
             save_path=save_path,
             is_show_fig=is_show_fig,
+            fig=fig,
+            ax=ax,
         )
     else:
         # Getting the main plot
         if self.parent is None:
             raise ParentMissingError("Error: The slot is not inside a Lamination")
         lam = self.parent
-        lam.plot(alpha=pi / self.Zs, is_show_fig=False)  # center slot on Ox axis
-        fig = plt.gcf()
-        ax = plt.gca()
+        fig, ax = lam.plot(
+            alpha=pi / self.Zs, is_show_fig=False, fig=fig, ax=ax
+        )  # center slot on Ox axis
         point_dict = self._comp_point_coordinate()
         if self.is_outwards():
             sign = +1
@@ -110,17 +130,6 @@ def plot_schematics(
                 is_arrow=True,
                 fontsize=SC_FONT_SIZE,
             )
-            # Wmag
-            plot_quote(
-                Z1=point_dict["ZM2"],
-                Zlim1=point_dict["ZM2"] - sign * 0.5 * self.Hmag,
-                Zlim2=point_dict["ZM3"] - sign * 0.5 * self.Hmag,
-                Z2=point_dict["ZM3"],
-                offset_label=0.25 * self.Hmag,
-                fig=fig,
-                ax=ax,
-                label="Wmag",
-            )
             # H0
             line = Segment(point_dict["Z1"], point_dict["Z2"])
             line.plot(
@@ -133,19 +142,31 @@ def plot_schematics(
                 is_arrow=True,
                 fontsize=SC_FONT_SIZE,
             )
-            # Hmag
-            Zlim1 = point_dict["Z3"] - sign * self.Hmag
-            Zlim2 = point_dict["Z3"]
-            plot_quote(
-                point_dict["ZM3"],
-                Zlim1,
-                Zlim2,
-                point_dict["ZM4"],
-                offset_label=1j * 0.2 * self.Hmag,
-                fig=fig,
-                ax=ax,
-                label="Hmag",
-            )
+            if type_add_active != 0:
+                # Wmag
+                plot_quote(
+                    Z1=point_dict["ZM2"],
+                    Zlim1=point_dict["ZM2"] - sign * 0.5 * self.Hmag,
+                    Zlim2=point_dict["ZM3"] - sign * 0.5 * self.Hmag,
+                    Z2=point_dict["ZM3"],
+                    offset_label=0.25 * self.Hmag,
+                    fig=fig,
+                    ax=ax,
+                    label="Wmag",
+                )
+                # Hmag
+                Zlim1 = point_dict["Z3"] - sign * self.Hmag
+                Zlim2 = point_dict["Z3"]
+                plot_quote(
+                    point_dict["ZM3"],
+                    Zlim1,
+                    Zlim2,
+                    point_dict["ZM4"],
+                    offset_label=1j * 0.2 * self.Hmag,
+                    fig=fig,
+                    ax=ax,
+                    label="Hmag",
+                )
 
         if is_add_main_line:
             # Ox axis
@@ -183,7 +204,7 @@ def plot_schematics(
         W = self.W0 / 2 * 1.4
         Rint, Rext = self.comp_radius()
 
-        plt.axis("equal")
+        ax.axis("equal")
         ax.set_xlim(Rint, Rext)
         ax.set_ylim(-W, W)
         manager = plt.get_current_fig_manager()
@@ -196,7 +217,8 @@ def plot_schematics(
         # Save / Show
         if save_path is not None:
             fig.savefig(save_path)
-            plt.close()
+            plt.close(fig=fig)
 
         if is_show_fig:
             fig.show()
+        return fig, ax
