@@ -1,3 +1,4 @@
+from msilib import type_binary
 import matplotlib.pyplot as plt
 from numpy import pi, exp
 
@@ -33,6 +34,8 @@ def plot_schematics(
     type_add_active=True,
     save_path=None,
     is_show_fig=True,
+    fig=None,
+    ax=None,
 ):
     """Plot the schematics of the slot
 
@@ -40,8 +43,8 @@ def plot_schematics(
     ----------
     self : SlotM11
         A SlotM11 object
-    is_default : bool
-        True: plot default schematics, else use current slot values
+    is_default : int
+        0: current slot values, 1: default internal rotor schematics, 2: default external stator schematics
     is_add_point_label : bool
         True to display the name of the points (Z1, Z2....)
     is_add_schematics : bool
@@ -54,15 +57,31 @@ def plot_schematics(
         full path including folder, name and extension of the file to save if save_path is not None
     is_show_fig : bool
         To call show at the end of the method
+    fig : Matplotlib.figure.Figure
+        existing figure to use if None create a new one
+    ax : Matplotlib.axes.Axes object
+        Axis on which to plot the data
+
+    Returns
+    -------
+    fig : Matplotlib.figure.Figure
+        Figure containing the schematics
+    ax : Matplotlib.axes.Axes object
+        Axis containing the schematics
     """
 
     # Use some default parameter
     if is_default:
         slot = type(self)(Zs=8, H0=20e-3, W0=pi / 8, Hmag=15e-3, Wmag=pi / 8 * 0.75)
-        lam = LamSlot(
-            Rint=0.1, Rext=0.135, is_internal=True, is_stator=False, slot=slot
-        )
-        slot.plot_schematics(
+        if is_default == 1:  # Internal Rotor schematics
+            lam = LamSlot(
+                Rint=0.1, Rext=0.135, is_internal=True, is_stator=False, slot=slot
+            )
+        else:  # External Stator schematics
+            lam = LamSlot(
+                Rint=0.1, Rext=0.135, is_internal=False, is_stator=True, slot=slot
+            )
+        return slot.plot_schematics(
             is_default=False,
             is_add_point_label=is_add_point_label,
             is_add_schematics=is_add_schematics,
@@ -70,15 +89,17 @@ def plot_schematics(
             type_add_active=type_add_active,
             save_path=save_path,
             is_show_fig=is_show_fig,
+            fig=fig,
+            ax=ax,
         )
     else:
         # Getting the main plot
         if self.parent is None:
             raise ParentMissingError("Error: The slot is not inside a Lamination")
         lam = self.parent
-        lam.plot(alpha=pi / self.Zs, is_show_fig=False)  # center slot on Ox axis
-        fig = plt.gcf()
-        ax = plt.gca()
+        fig, ax = lam.plot(
+            alpha=pi / self.Zs, is_show_fig=False, fig=fig, ax=ax
+        )  # center slot on Ox axis
         point_dict = self._comp_point_coordinate()
         if self.is_outwards():
             sign = +1
@@ -116,23 +137,6 @@ def plot_schematics(
                 offset_label=sign * self.H0 * 0.3,
                 fontsize=SC_FONT_SIZE,
             )
-            # Wmag
-            R = self.get_Rbo() + sign * (self.H0 - self.Hmag * 1.1)
-            line = Arc1(
-                begin=R * exp(-1j * self.Wmag / 2),
-                end=R * exp(1j * self.Wmag / 2),
-                radius=R,
-                is_trigo_direction=True,
-            )
-            line.plot(
-                fig=fig,
-                ax=ax,
-                color=ARROW_COLOR,
-                linewidth=ARROW_WIDTH,
-                label="Wmag",
-                offset_label=-1 * sign * self.H0 * 0.2,
-                fontsize=SC_FONT_SIZE,
-            )
             # H0
             line = Segment(point_dict["Z1"], point_dict["Z2"])
             line.plot(
@@ -145,18 +149,36 @@ def plot_schematics(
                 is_arrow=True,
                 fontsize=SC_FONT_SIZE,
             )
-            # Hmag
-            line = Segment(point_dict["ZM3"], point_dict["ZM4"])
-            line.plot(
-                fig=fig,
-                ax=ax,
-                color=ARROW_COLOR,
-                linewidth=ARROW_WIDTH,
-                label="Hmag",
-                offset_label=1j * point_dict["Z4"].imag * 0.2,
-                is_arrow=True,
-                fontsize=SC_FONT_SIZE,
-            )
+            if type_add_active != 0:
+                # Wmag
+                R = self.get_Rbo() + sign * (self.H0 - self.Hmag * 1.1)
+                line = Arc1(
+                    begin=R * exp(-1j * self.Wmag / 2),
+                    end=R * exp(1j * self.Wmag / 2),
+                    radius=R,
+                    is_trigo_direction=True,
+                )
+                line.plot(
+                    fig=fig,
+                    ax=ax,
+                    color=ARROW_COLOR,
+                    linewidth=ARROW_WIDTH,
+                    label="Wmag",
+                    offset_label=-1 * sign * self.H0 * 0.2,
+                    fontsize=SC_FONT_SIZE,
+                )
+                # Hmag
+                line = Segment(point_dict["ZM3"], point_dict["ZM4"])
+                line.plot(
+                    fig=fig,
+                    ax=ax,
+                    color=ARROW_COLOR,
+                    linewidth=ARROW_WIDTH,
+                    label="Hmag",
+                    offset_label=1j * point_dict["Z4"].imag * 0.2,
+                    is_arrow=True,
+                    fontsize=SC_FONT_SIZE,
+                )
 
         if is_add_main_line:
             # Ox axis
@@ -186,24 +208,25 @@ def plot_schematics(
                 linestyle=MAIN_LINE_STYLE,
                 linewidth=MAIN_LINE_WIDTH,
             )
-            # ZM1 Line
-            line = Segment(0, Rbo * 2 * exp(-1j * self.Wmag / 2))
-            line.plot(
-                fig=fig,
-                ax=ax,
-                color=MAIN_LINE_COLOR,
-                linestyle=MAIN_LINE_STYLE,
-                linewidth=MAIN_LINE_WIDTH,
-            )
-            # ZM2 Line
-            line = Segment(0, Rbo * 2 * exp(1j * self.Wmag / 2))
-            line.plot(
-                fig=fig,
-                ax=ax,
-                color=MAIN_LINE_COLOR,
-                linestyle=MAIN_LINE_STYLE,
-                linewidth=MAIN_LINE_WIDTH,
-            )
+            if type_add_active != 0:
+                # ZM1 Line
+                line = Segment(0, Rbo * 2 * exp(-1j * self.Wmag / 2))
+                line.plot(
+                    fig=fig,
+                    ax=ax,
+                    color=MAIN_LINE_COLOR,
+                    linestyle=MAIN_LINE_STYLE,
+                    linewidth=MAIN_LINE_WIDTH,
+                )
+                # ZM2 Line
+                line = Segment(0, Rbo * 2 * exp(1j * self.Wmag / 2))
+                line.plot(
+                    fig=fig,
+                    ax=ax,
+                    color=MAIN_LINE_COLOR,
+                    linestyle=MAIN_LINE_STYLE,
+                    linewidth=MAIN_LINE_WIDTH,
+                )
             # Top arc
             line = Arc1(
                 begin=point_dict["Z1"],
@@ -227,10 +250,13 @@ def plot_schematics(
             )
 
         # Zooming and cleaning
-        W = point_dict["Z4"].imag * 1.2
+        if self.is_outwards():
+            W = point_dict["Z4"].imag * 1.4
+        else:
+            W = point_dict["Z4"].imag * 1.2
         Rint, Rext = self.comp_radius()
 
-        plt.axis("equal")
+        ax.axis("equal")
         ax.set_xlim(Rint, Rext)
         ax.set_ylim(-W, W)
         manager = plt.get_current_fig_manager()
@@ -243,7 +269,8 @@ def plot_schematics(
         # Save / Show
         if save_path is not None:
             fig.savefig(save_path)
-            plt.close()
+            plt.close(fig=fig)
 
         if is_show_fig:
             fig.show()
+        return fig, ax
