@@ -30,9 +30,11 @@ def plot_schematics(
     is_add_point_label=False,
     is_add_schematics=True,
     is_add_main_line=True,
-    type_add_active=True,
+    type_add_active=1,
     save_path=None,
     is_show_fig=True,
+    fig=None,
+    ax=None,
 ):
     """Plot the schematics of the slot
 
@@ -49,18 +51,29 @@ def plot_schematics(
     is_add_main_line : bool
         True to display "main lines" (slot opening and 0x axis)
     type_add_active : int
-        0: No active surface, 1: active surface as winding, 2: active surface as magnet
+        0: No active surface, 1: active surface as winding, 2: active surface as magnet, 3: active surface as winding + wedges
     save_path : str
         full path including folder, name and extension of the file to save if save_path is not None
     is_show_fig : bool
         To call show at the end of the method
+    fig : Matplotlib.figure.Figure
+        existing figure to use if None create a new one
+    ax : Matplotlib.axes.Axes object
+        Axis on which to plot the data
+
+    Returns
+    -------
+    fig : Matplotlib.figure.Figure
+        Figure containing the schematics
+    ax : Matplotlib.axes.Axes object
+        Axis containing the schematics
     """
 
     # Use some default parameter
     if is_default:
         slot = type(self)(Zs=12, W0=pi / 24, R1=20e-3, H0=20e-3, H2=80e-3, W3=30e-3)
         lam = LamSlot(Rint=0.135, Rext=0.3, is_internal=True, is_stator=True, slot=slot)
-        slot.plot_schematics(
+        return slot.plot_schematics(
             is_default=False,
             is_add_point_label=is_add_point_label,
             is_add_schematics=is_add_schematics,
@@ -68,15 +81,17 @@ def plot_schematics(
             type_add_active=type_add_active,
             save_path=save_path,
             is_show_fig=is_show_fig,
+            fig=fig,
+            ax=ax,
         )
     else:
         # Getting the main plot
         if self.parent is None:
             raise ParentMissingError("Error: The slot is not inside a Lamination")
         lam = self.parent
-        lam.plot(alpha=pi / self.Zs, is_show_fig=False)  # center slot on Ox axis
-        fig = plt.gcf()
-        ax = plt.gca()
+        fig, ax = lam.plot(
+            alpha=pi / self.Zs, is_show_fig=False, fig=fig, ax=ax
+        )  # center slot on Ox axis
         point_dict = self._comp_point_coordinate()
         if self.is_outwards():
             sign = 1
@@ -263,11 +278,14 @@ def plot_schematics(
                 linewidth=MAIN_LINE_WIDTH,
             )
 
-        if type_add_active == 1:
-            self.plot_active(fig=fig, is_show_fig=False)
-        elif type_add_active == 2:
+        if type_add_active in [1, 3]:  # Wind and Wedge
+            is_add_wedge = type_add_active == 3
+            self.plot_active(fig=fig, is_show_fig=False, is_add_wedge=is_add_wedge)
+        elif type_add_active == 2:  # Magnet
             self.plot_active(
-                fig=fig, is_show_fig=False, enforced_default_color=MAGNET_COLOR
+                fig=fig,
+                is_show_fig=False,
+                enforced_default_color=MAGNET_COLOR,
             )
 
         # Zooming and cleaning
@@ -275,7 +293,7 @@ def plot_schematics(
         Rint = min(point_dict["Z6"].real, point_dict["Z1"].real)
         Rext = max(point_dict["Z6"].real, point_dict["Z1"].real)
 
-        plt.axis("equal")
+        ax.axis("equal")
         ax.set_xlim(Rint, Rext)
         ax.set_ylim(-W, W)
         manager = plt.get_current_fig_manager()
@@ -288,7 +306,8 @@ def plot_schematics(
         # Save / Show
         if save_path is not None:
             fig.savefig(save_path)
-            plt.close()
+            plt.close(fig=fig)
 
         if is_show_fig:
             fig.show()
+        return fig, ax
