@@ -19,7 +19,8 @@ def comp_surface(self):
 
     """
 
-    [Z1, Z2, Z3, Z4, Z5, Z6, Z7, Z8, Z9, Z10] = self._comp_point_coordinate()
+    point_dict = self._comp_point_coordinate()
+    Z5 = point_dict["Z5"]
     Rext = self.get_Rbo()
     Rint = abs(Z5)
 
